package server_test

import (
	"flag"
	"fmt"
	"fusenapi/server/home-user-auth/internal/config"
	"fusenapi/server/home-user-auth/internal/handler"
	"fusenapi/server/home-user-auth/internal/svc"
	"testing"

	"github.com/474420502/requests"
	"github.com/zeromicro/go-zero/core/conf"
	"github.com/zeromicro/go-zero/rest"
)

var testConfigFile = flag.String("f", "../etc/home-user-auth.yaml", "the config file")
var cnf config.Config

func GetTestServer() *rest.Server {
	flag.Parse()

	conf.MustLoad(*testConfigFile, &cnf)

	server := rest.MustNewServer(cnf.RestConf)
	defer server.Stop()

	ctx := svc.NewServiceContext(cnf)
	handler.RegisterHandlers(server, ctx)

	fmt.Printf("Starting server at %s:%d...\n", cnf.Host, cnf.Port)
	return server
}

func TestCaseAddressList(t *testing.T) {
	server := GetTestServer()

	ses := requests.NewSession()
	tp := ses.Post(fmt.Sprintf("http://%s:%d/user/login", cnf.Host, cnf.Port))
	tp.SetBodyJson(map[string]interface{}{
		"name": "devenv@sina.cn",
		"pwd":  "$2y$13$6UFDMZQMEfqFYiNLpiUCi.B3fpvGEamPAjIgzUqv/u7jT05nB3pOC",
	})
	resp, err := tp.TestInServer(server)
	if err != nil {
		t.Error(err)
	}
	result := resp.Json()
	token := result.Get("data.token")
	if !token.Exists() {
		t.Error("data.token is not exists")
	}
	ses.Header.Add("Authorization", token.String())

	resp, err = ses.Get(fmt.Sprintf("http://%s:%d/user/address-list", cnf.Host, cnf.Port)).TestInServer(server)
	if err != nil {
		t.Error(err)
	}
	result = resp.Json().Get("code")
	if !result.Exists() {
		t.Error("code is not exists")
	}
	if result.Int() != 200 {
		t.Error("code != 200")
	}

	result = resp.Json().Get("msg")
	if !result.Exists() {
		t.Error("msg is not exists")
	}
	if result.String() != "success" {
		t.Error(result.String())
	}
}
